==> open-xchange-usm_6.22.0.orig.tar.bz2: open-xchange-usm-6.22.0/com.openexchange.usm.mapping/src/com/openexchange/usm/mapping/FolderIdMapping.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.mapping;

import com.openexchange.usm.api.database.DatabaseAccessException;
import com.openexchange.usm.api.exceptions.USMSQLException;

public interface FolderIdMapping {

	/**
	 * Retrieves a short ID for a long ID. If a short ID was previously restored, retrieves that short
	 * ID. Otherwise, it will generate and store a new short ID and return it.
	 * 
	 * @param longID
	 * @return the associated short id
	 */
	public int getShortID(String longID) throws DatabaseAccessException, USMSQLException;

	/**
	 * Deletes one or more (long) folder IDs from the db.
	 * @param id
	 */
	public void delete(String... id) throws DatabaseAccessException, USMSQLException;

	/**
	 * Deletes all but the specified folder ID entries from the db.
	 * @param longID
	 */
	void retain(String... longID) throws DatabaseAccessException, USMSQLException;

	/**
	 * Returns the longID associated with the given shortID.
	 * @param shortID
	 * @return the long id or null if no id is found
	 */
	public String getLongID(int shortID) throws USMSQLException;
}

==> open-xchange-usm_7.0.0.orig.tar.bz2: open-xchange-usm-7.0.0/com.openexchange.usm.mapping/src/com/openexchange/usm/mapping/FolderIdMapping.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.mapping;

import java.io.Serializable;
import com.openexchange.usm.api.database.DatabaseAccessException;
import com.openexchange.usm.api.exceptions.USMSQLException;

public interface FolderIdMapping extends Serializable {

	/**
	 * Retrieves a short ID for a long ID. If a short ID was previously restored, retrieves that short
	 * ID. Otherwise, it will generate and store a new short ID and return it.
	 * 
	 * @param longID
	 * @return the associated short id
	 */
	public int getShortID(String longID) throws DatabaseAccessException, USMSQLException;

	/**
	 * Deletes one or more (long) folder IDs from the db.
	 * @param id
	 */
	public void delete(String... id) throws DatabaseAccessException, USMSQLException;

	/**
	 * Deletes all but the specified folder ID entries from the db.
	 * @param longID
	 */
	void retain(String... longID) throws DatabaseAccessException, USMSQLException;

	/**
	 * Returns the longID associated with the given shortID.
	 * @param shortID
	 * @return the long id or null if no id is found
	 */
	public String getLongID(int shortID) throws USMSQLException;
}
